package com.qmth.distributed.print.api;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.distributed.print.business.bean.result.EditResult;
import com.qmth.distributed.print.business.service.ConditionService;
import com.qmth.teachcloud.common.annotation.OperationLogDetail;
import com.qmth.teachcloud.common.bean.params.BasicCollegeParams;
import com.qmth.teachcloud.common.bean.result.BasicCollegeResult;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.entity.SysUser;
import com.qmth.teachcloud.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.common.enums.log.CustomizedOperationTypeEnum;
import com.qmth.teachcloud.common.service.BasicCollegeService;
import com.qmth.teachcloud.common.util.Result;
import com.qmth.teachcloud.common.util.ResultUtil;
import com.qmth.teachcloud.common.util.ServletUtil;
import io.swagger.annotations.*;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 查询条件
 */
@Api(tags = "查询条件Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_BASIC + "/condition")
public class ConditionController {
    @Resource
    private ConditionService conditionService;

    @ApiOperation(value = "学期")
    @RequestMapping(value = "/list_semester", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = BasicCollegeResult.class)})
    public Result listSemester(@ApiParam(value = "启用/禁用") @RequestParam(required = false) Boolean enable) {
        return ResultUtil.ok(conditionService.listSemester(enable));
    }

    @ApiOperation(value = "考试")
    @RequestMapping(value = "/list_exam", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = BasicCollegeResult.class)})
    public Result listExam(@ApiParam(value = "学期ID") @RequestParam(required = false) Long semesterId,
                           @ApiParam(value = "启用/禁用") @RequestParam(required = false) Boolean enable) {
        return ResultUtil.ok(conditionService.listExam(semesterId, enable));
    }

    @ApiOperation(value = "课程")
    @RequestMapping(value = "/list_course", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = BasicCollegeResult.class)})
    public Result listCourse(@ApiParam(value = "学期ID") @RequestParam(required = false) Long semesterId,
                             @ApiParam(value = "考试ID") @RequestParam(required = false) Long examId,
                             @ApiParam(value = "启用/禁用") @RequestParam(required = false) Boolean enable,
                             @RequestParam(value = "printPlanId", required = false) List<String> printPlanId) {
        return ResultUtil.ok(conditionService.listCourse(semesterId, examId, enable, printPlanId));
    }

    @ApiOperation(value = "试卷编号")
    @RequestMapping(value = "/list_paper_number", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = BasicCollegeResult.class)})
    public Result listPaperNumber(@ApiParam(value = "学期ID") @RequestParam(required = false) Long semesterId,
                                  @ApiParam(value = "考试ID") @RequestParam(required = false) Long examId,
                                  @ApiParam(value = "课程代码") @RequestParam(required = false) String courseCode,
                                  @RequestParam(value = "printPlanId", required = false) List<String> printPlanId) {
        return ResultUtil.ok(conditionService.listPaperNumber(semesterId, examId, courseCode, printPlanId));
    }

    @ApiOperation(value = "印刷计划")
    @RequestMapping(value = "/list_print_plan", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = BasicCollegeResult.class)})
    public Result listPrintPlan(@ApiParam(value = "学期ID") @RequestParam(required = false) Long semesterId,
                                @ApiParam(value = "考试ID") @RequestParam(required = false) Long examId) {
        return ResultUtil.ok(conditionService.listPrintPlan(semesterId, examId));
    }

    @ApiOperation(value = "试卷编号")
    @RequestMapping(value = "/list_clazz", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = BasicCollegeResult.class)})
    public Result listClazz(@ApiParam(value = "学期ID") @RequestParam(required = false) Long semesterId,
                                  @ApiParam(value = "考试ID") @RequestParam(required = false) Long examId,
                                  @ApiParam(value = "课程代码") @RequestParam(required = false) String courseCode) {
        return ResultUtil.ok(conditionService.listClazz(semesterId, examId, courseCode));
    }
}
